# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/database_error.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/command/v1/database_error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0device/heat_pump/command/v1/database_error.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\"\\\n\rDatabaseError\x12:\n\nerror_type\x18\x01 \x01(\x0e\x32&.device.heat_pump.command.v1.ErrorType\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\t*\xfc\x01\n\tErrorType\x12\x1a\n\x16\x45RROR_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45RROR_TYPE_MISSING_KEY\x10\x01\x12#\n\x1f\x45RROR_TYPE_FAILED_TO_STORE_DATA\x10\x02\x12\"\n\x1e\x45RROR_TYPE_FAILED_TO_LOAD_DATA\x10\x03\x12\"\n\x1e\x45RROR_TYPE_FAILED_TO_SERIALIZE\x10\x04\x12$\n ERROR_TYPE_FAILED_TO_DESERIALIZE\x10\x05\x12$\n ERROR_TYPE_FAILED_TO_DELETE_DATA\x10\x06\x42\xce\x01\n-com.aira.contract.device.heat_pump.command.v1B\x12\x44\x61tabaseErrorProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.database_error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.aira.contract.device.heat_pump.command.v1B\022DatabaseErrorProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_ERRORTYPE']._serialized_start=176
  _globals['_ERRORTYPE']._serialized_end=428
  _globals['_DATABASEERROR']._serialized_start=81
  _globals['_DATABASEERROR']._serialized_end=173
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/util/v1/water_tank_size.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/util/v1/water_tank_size.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.device/heat_pump/util/v1/water_tank_size.proto\x12\x18\x64\x65vice.heat_pump.util.v1*\xf0\x01\n\rWaterTankSize\x12\x1f\n\x1bWATER_TANK_SIZE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aWATER_TANK_SIZE_100_LITERS\x10\x01\x12\x1e\n\x1aWATER_TANK_SIZE_150_LITERS\x10\x03\x12\x1e\n\x1aWATER_TANK_SIZE_200_LITERS\x10\x04\x12\x1e\n\x1aWATER_TANK_SIZE_250_LITERS\x10\x02\x12\x1e\n\x1aWATER_TANK_SIZE_300_LITERS\x10\x06\x12\x18\n\x14WATER_TANK_SIZE_NONE\x10\x07\"\x04\x08\x05\x10\x05\x42\xbf\x01\n*com.aira.contract.device.heat_pump.util.v1B\x12WaterTankSizeProtoP\x01\xa2\x02\x03\x44HU\xaa\x02\x17\x44\x65vice.HeatPump.Util.V1\xca\x02\x17\x44\x65vice\\HeatPump\\Util\\V1\xe2\x02#Device\\HeatPump\\Util\\V1\\GPBMetadata\xea\x02\x1a\x44\x65vice::HeatPump::Util::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.util.v1.water_tank_size_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.aira.contract.device.heat_pump.util.v1B\022WaterTankSizeProtoP\001\242\002\003DHU\252\002\027Device.HeatPump.Util.V1\312\002\027Device\\HeatPump\\Util\\V1\342\002#Device\\HeatPump\\Util\\V1\\GPBMetadata\352\002\032Device::HeatPump::Util::V1'
  _globals['_WATERTANKSIZE']._serialized_start=77
  _globals['_WATERTANKSIZE']._serialized_end=317
# @@protoc_insertion_point(module_scope)


""" Main class for the Aira Home library, providing high-level access to auth and control the heatpump. """
# aira_home.py
from .config import Settings
from .auth import CognitoAuth
from .device.v1 import devices_pb2, devices_pb2_grpc
from .device.heat_pump.cloud.v1 import service_pb2, service_pb2_grpc
from .device.heat_pump.command.v1 import command_pb2
from google.protobuf import timestamp_pb2
from grpc import secure_channel, ssl_channel_credentials
from datetime import datetime
from .utils import Utils, UnknownCommandException

class AiraHome:
    def __init__(self,
                 user_pool_id: str = Settings.USER_POOL_IDS[0],
                 client_id: str = Settings.CLIENT_ID,
                 aira_backend: str = Settings.AIRA_BACKEND,
                 user_agent: str = Settings.USER_AGENT,
                 app_package: str = Settings.APP_PACKAGE,
                 app_version: str = Settings.APP_VERSION):
        """ Initialize the AiraHome instance with user pool ID and client ID. """
        self.user_pool_id = user_pool_id
        self.client_id = client_id
        self._auth = CognitoAuth(self.user_pool_id, self.client_id)
        self.user_agent = user_agent
        self.app_package = app_package
        self.app_version = app_version

        self._channel = secure_channel(aira_backend, ssl_channel_credentials())
        self._devices_stub = devices_pb2_grpc.DevicesServiceStub(self._channel)
        self._services_stub = service_pb2_grpc.HeatPumpCloudServiceStub(self._channel)

    # Auth methods
    def login_with_credentials(self, username: str, password: str):
        """ Login using username and password. """
        return self._auth.login_credentials(username, password)

    def login_with_tokens(self, id_token: str, access_token: str, refresh_token: str):
        """ Login using existing tokens. """
        return self._auth.login_tokens(id_token, access_token, refresh_token)

    def _get_id_token(self):
        """ Get the ID token from the TokenManager. """
        tokens = self._auth.get_tokens()
        if tokens:
            return tokens.get_id_token()
        return None

    def _get_metadatas(self):
        """ Create Metadatas instance with the current settings. """
        id_token = self._get_id_token()
        metadata = (
            ('authorization', f'Bearer {id_token}'),
            ('user-agent', self.user_agent),
            ('app-package', self.app_package),
            ('app-version', self.app_version)
        )
        return metadata

    def get_tokens(self):
        """ Get the TokenManager instance if available. """
        return self._auth.get_tokens()
    
    # Heatpump ro methods
    def get_devices(self, raw: bool = False):
        """ Get the list of devices. """
        response = self._devices_stub.GetDevices(
            devices_pb2.GetDevicesRequest(),
            metadata=self._get_metadatas()
        )
        if raw:
            return response

        return Utils.convert_to_dict(response)

    def get_device_details(self, device_id, raw: bool = False):
        """ Get the details of a specific device. """
        _id = Utils.convert_to_uuid_list(device_id)[0]

        response = self._devices_stub.GetDeviceDetails(
            devices_pb2.GetDeviceDetailsRequest(id=_id),
            metadata=self._get_metadatas()
        )
        if raw:
            return response

        return Utils.convert_to_dict(response)

    def get_states(self, device_ids, raw: bool = False):
        """ Get the states of a specific device. """
        heat_pump_ids = Utils.convert_to_uuid_list(device_ids)

        response = self._devices_stub.GetStates(
            devices_pb2.GetStatesRequest(heat_pump_ids=heat_pump_ids),
            metadata=self._get_metadatas()
        )
        if raw:
            return response

        return Utils.convert_to_dict(response)

    # Heatpump wo methods
    def send_command(self, device_id, command_in, timestamp = None, raw: bool = False, **kwargs):
        """ Send a command to a specific device. """
        heat_pump_id = Utils.convert_to_uuid_list(device_id)[0]
        
        if timestamp is None:
            _time = timestamp_pb2.Timestamp(seconds=0, nanos=0)
        elif isinstance(timestamp, timestamp_pb2.Timestamp):
            _time = timestamp
        elif isinstance(timestamp, int):
            _time = timestamp_pb2.Timestamp(seconds=timestamp, nanos=0)
        elif isinstance(timestamp, datetime):
            _time = timestamp_pb2.Timestamp(seconds=int(timestamp.timestamp()), nanos=0)

        if isinstance(command_in, str) and command_in in Settings.ALLOWED_COMMANDS:
            command_class = type(getattr(command_pb2.Command(), command_in)) # Get the command class dynamically
            command = command_pb2.Command(**{command_in: command_class(**kwargs)}, time=_time) # Create the command instance dynamically
        else:
            raise UnknownCommandException(f"Unknown command: {command_in}. Allowed commands are: {Settings.ALLOWED_COMMANDS}")

        response = self._services_stub.SendCommand(
            service_pb2.SendCommandRequest(heat_pump_id=heat_pump_id,
                                           command=command),
            metadata=self._get_metadatas()
        )
        if raw:
            return response

        return Utils.convert_to_dict(response)
    
    # Heatpump stream methods
    def stream_command_progress(self, command_id, raw: bool = False):
        """ Stream the progress of a command. """
        command_uuid = Utils.convert_to_uuid_list(command_id)[0]

        response = self._services_stub.StreamCommandProgress(
            service_pb2.StreamCommandProgressRequest(command_id=command_uuid),
            metadata=self._get_metadatas()
        )
        if raw:
            return response

        return map(Utils.convert_to_dict, response)

    def stream_states(self, device_ids, raw: bool = False):
        """ Stream the states of a specific device. """
        heat_pump_ids = Utils.convert_to_uuid_list(device_ids)

        response = self._devices_stub.StreamStates(
            devices_pb2.StreamStatesRequest(heat_pump_ids=heat_pump_ids),
            metadata=self._get_metadatas()
        )
        if raw:
            return response

        return map(Utils.convert_to_dict, response)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import service_pb2 as device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in device/heat_pump/cloud/v1/service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class HeatPumpCloudServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendCommand = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/SendCommand',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SendCommandRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SendCommandResponse.FromString,
                _registered_method=True)
        self.StreamCommandProgress = channel.unary_stream(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/StreamCommandProgress',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.StreamCommandProgressRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.StreamCommandProgressResponse.FromString,
                _registered_method=True)
        self.ScheduleAwayMode = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/ScheduleAwayMode',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleAwayModeRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleAwayModeResponse.FromString,
                _registered_method=True)
        self.GetScheduledAwayMode = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/GetScheduledAwayMode',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetScheduledAwayModeRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetScheduledAwayModeResponse.FromString,
                _registered_method=True)
        self.DeleteScheduledAwayMode = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/DeleteScheduledAwayMode',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledAwayModeRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledAwayModeResponse.FromString,
                _registered_method=True)
        self.ScheduleNightMode = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/ScheduleNightMode',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleNightModeRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleNightModeResponse.FromString,
                _registered_method=True)
        self.DeleteScheduledNightMode = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/DeleteScheduledNightMode',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledNightModeRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledNightModeResponse.FromString,
                _registered_method=True)
        self.SetDhwSchedule = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/SetDhwSchedule',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetDhwScheduleRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetDhwScheduleResponse.FromString,
                _registered_method=True)
        self.GetDhwSchedule = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/GetDhwSchedule',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetDhwScheduleRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetDhwScheduleResponse.FromString,
                _registered_method=True)
        self.DeleteDhwSchedule = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/DeleteDhwSchedule',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteDhwScheduleRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteDhwScheduleResponse.FromString,
                _registered_method=True)
        self.SetLegionellaSchedule = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/SetLegionellaSchedule',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetLegionellaScheduleRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetLegionellaScheduleResponse.FromString,
                _registered_method=True)
        self.GetLegionellaSchedule = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/GetLegionellaSchedule',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetLegionellaScheduleRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetLegionellaScheduleResponse.FromString,
                _registered_method=True)
        self.DeleteLegionellaSchedule = channel.unary_unary(
                '/device.heat_pump.cloud.v1.HeatPumpCloudService/DeleteLegionellaSchedule',
                request_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteLegionellaScheduleRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteLegionellaScheduleResponse.FromString,
                _registered_method=True)


class HeatPumpCloudServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamCommandProgress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScheduleAwayMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScheduledAwayMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteScheduledAwayMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScheduleNightMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteScheduledNightMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDhwSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDhwSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDhwSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetLegionellaSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLegionellaSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLegionellaSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HeatPumpCloudServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.SendCommand,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SendCommandRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SendCommandResponse.SerializeToString,
            ),
            'StreamCommandProgress': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamCommandProgress,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.StreamCommandProgressRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.StreamCommandProgressResponse.SerializeToString,
            ),
            'ScheduleAwayMode': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleAwayMode,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleAwayModeRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleAwayModeResponse.SerializeToString,
            ),
            'GetScheduledAwayMode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScheduledAwayMode,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetScheduledAwayModeRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetScheduledAwayModeResponse.SerializeToString,
            ),
            'DeleteScheduledAwayMode': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteScheduledAwayMode,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledAwayModeRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledAwayModeResponse.SerializeToString,
            ),
            'ScheduleNightMode': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleNightMode,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleNightModeRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleNightModeResponse.SerializeToString,
            ),
            'DeleteScheduledNightMode': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteScheduledNightMode,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledNightModeRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledNightModeResponse.SerializeToString,
            ),
            'SetDhwSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDhwSchedule,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetDhwScheduleRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetDhwScheduleResponse.SerializeToString,
            ),
            'GetDhwSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDhwSchedule,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetDhwScheduleRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetDhwScheduleResponse.SerializeToString,
            ),
            'DeleteDhwSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDhwSchedule,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteDhwScheduleRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteDhwScheduleResponse.SerializeToString,
            ),
            'SetLegionellaSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLegionellaSchedule,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetLegionellaScheduleRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetLegionellaScheduleResponse.SerializeToString,
            ),
            'GetLegionellaSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLegionellaSchedule,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetLegionellaScheduleRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetLegionellaScheduleResponse.SerializeToString,
            ),
            'DeleteLegionellaSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLegionellaSchedule,
                    request_deserializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteLegionellaScheduleRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteLegionellaScheduleResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'device.heat_pump.cloud.v1.HeatPumpCloudService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('device.heat_pump.cloud.v1.HeatPumpCloudService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class HeatPumpCloudService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/SendCommand',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SendCommandRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SendCommandResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamCommandProgress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/StreamCommandProgress',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.StreamCommandProgressRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.StreamCommandProgressResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScheduleAwayMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/ScheduleAwayMode',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleAwayModeRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleAwayModeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetScheduledAwayMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/GetScheduledAwayMode',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetScheduledAwayModeRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetScheduledAwayModeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteScheduledAwayMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/DeleteScheduledAwayMode',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledAwayModeRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledAwayModeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScheduleNightMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/ScheduleNightMode',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleNightModeRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.ScheduleNightModeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteScheduledNightMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/DeleteScheduledNightMode',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledNightModeRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteScheduledNightModeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetDhwSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/SetDhwSchedule',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetDhwScheduleRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetDhwScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDhwSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/GetDhwSchedule',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetDhwScheduleRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetDhwScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDhwSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/DeleteDhwSchedule',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteDhwScheduleRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteDhwScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetLegionellaSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/SetLegionellaSchedule',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetLegionellaScheduleRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.SetLegionellaScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetLegionellaSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/GetLegionellaSchedule',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetLegionellaScheduleRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.GetLegionellaScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteLegionellaSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.cloud.v1.HeatPumpCloudService/DeleteLegionellaSchedule',
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteLegionellaScheduleRequest.SerializeToString,
            device_dot_heat__pump_dot_cloud_dot_v1_dot_service__pb2.DeleteLegionellaScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/configure_heat_pump.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/command/v1/configure_heat_pump.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...config.v1 import config_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5device/heat_pump/command/v1/configure_heat_pump.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\x1a\'device/heat_pump/config/v1/config.proto\"G\n\x11\x43onfigureHeatPump\x12\x32\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\".device.heat_pump.config.v1.Config\"`\n\x0e\x43\x63vConfigError\x12=\n\x04\x63ode\x18\x01 \x01(\x0e\x32/.device.heat_pump.command.v1.CcvConfigErrorCode\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\t\"N\n\x0f\x43\x63vConfigErrors\x12;\n\x06\x65rrors\x18\x01 \x03(\x0b\x32+.device.heat_pump.command.v1.CcvConfigError\"h\n\x0b\x43onfigError\x12I\n\x11\x63\x63v_config_errors\x18\x01 \x01(\x0b\x32,.device.heat_pump.command.v1.CcvConfigErrorsH\x00\x42\x0e\n\x0c\x63onfig_error*\x8d\x06\n\x12\x43\x63vConfigErrorCode\x12%\n!CCV_CONFIG_ERROR_CODE_UNSPECIFIED\x10\x00\x12(\n$CCV_CONFIG_ERROR_CODE_SENSOR_SOURCES\x10\x01\x12-\n)CCV_CONFIG_ERROR_CODE_COMPRESSOR_SETTINGS\x10\x02\x12&\n\"CCV_CONFIG_ERROR_CODE_HEATING_MODE\x10\x03\x12(\n$CCV_CONFIG_ERROR_CODE_HEATING_SYSTEM\x10\x04\x12$\n CCV_CONFIG_ERROR_CODE_DHW_SYSTEM\x10\x05\x12#\n\x1f\x43\x43V_CONFIG_ERROR_CODE_AWAY_MODE\x10\x06\x12)\n%CCV_CONFIG_ERROR_CODE_HEATING_COOLING\x10\x07\x12+\n\'CCV_CONFIG_ERROR_CODE_OUTDOOR_UNIT_SIZE\x10\x08\x12\'\n#CCV_CONFIG_ERROR_CODE_FACTORY_RESET\x10\t\x12$\n CCV_CONFIG_ERROR_CODE_PUMP_SPEED\x10\n\x12*\n&CCV_CONFIG_ERROR_CODE_ALARM_THRESHOLDS\x10\x0b\x12/\n+CCV_CONFIG_ERROR_CODE_REBOOT_WAIT_TIMED_OUT\x10\x0c\x12+\n\'CCV_CONFIG_ERROR_CODE_ELECTRICITY_METER\x10\r\x12-\n)CCV_CONFIG_ERROR_CODE_INLINE_HEATER_STEPS\x10\x0e\x12$\n CCV_CONFIG_ERROR_CODE_NIGHT_MODE\x10\x0f\x12%\n!CCV_CONFIG_ERROR_CODE_FLOW_METERS\x10\x10\x12-\n)CCV_CONFIG_ERROR_CODE_ENERGY_BALANCY_KICK\x10\x11\x42\xd2\x01\n-com.aira.contract.device.heat_pump.command.v1B\x16\x43onfigureHeatPumpProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.configure_heat_pump_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.aira.contract.device.heat_pump.command.v1B\026ConfigureHeatPumpProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_CCVCONFIGERRORCODE']._serialized_start=485
  _globals['_CCVCONFIGERRORCODE']._serialized_end=1266
  _globals['_CONFIGUREHEATPUMP']._serialized_start=127
  _globals['_CONFIGUREHEATPUMP']._serialized_end=198
  _globals['_CCVCONFIGERROR']._serialized_start=200
  _globals['_CCVCONFIGERROR']._serialized_end=296
  _globals['_CCVCONFIGERRORS']._serialized_start=298
  _globals['_CCVCONFIGERRORS']._serialized_end=376
  _globals['_CONFIGERROR']._serialized_start=378
  _globals['_CONFIGERROR']._serialized_end=482
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_account/v2/user_invitation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'user_account/v2/user_invitation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%user_account/v2/user_invitation.proto\x12\x0fuser_account.v2\x1a\x12util/v2/uuid.proto\"\x82\x01\n\x1cInviteUserToHouseholdRequest\x12&\n\x0finviter_user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x15\n\rinvitee_email\x18\x02 \x01(\t\x12#\n\x0chousehold_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\"\x1f\n\x1dInviteUserToHouseholdResponse\"0\n\x17\x41\x63\x63\x65ptInvitationRequest\x12\x15\n\rinvitee_email\x18\x01 \x01(\t\"\x1a\n\x18\x41\x63\x63\x65ptInvitationResponse\"t\n\"GetInvitationsByHouseholdIdRequest\x12)\n\x12household_owner_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12#\n\x0chousehold_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\"Q\n#GetInvitationsByHouseholdIdResponse\x12*\n\x08invitees\x18\x01 \x03(\x0b\x32\x18.user_account.v2.Invitee\" \n\x07Invitee\x12\x15\n\rinvitee_email\x18\x01 \x01(\t\"}\n\x17\x44\x65leteInvitationRequest\x12&\n\x0finviter_user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x15\n\rinvitee_email\x18\x02 \x01(\t\x12#\n\x0chousehold_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\"\x1a\n\x18\x44\x65leteInvitationResponse2\xec\x03\n\x15UserInvitationService\x12v\n\x15InviteUserToHousehold\x12-.user_account.v2.InviteUserToHouseholdRequest\x1a..user_account.v2.InviteUserToHouseholdResponse\x12g\n\x10\x41\x63\x63\x65ptInvitation\x12(.user_account.v2.AcceptInvitationRequest\x1a).user_account.v2.AcceptInvitationResponse\x12\x88\x01\n\x1bGetInvitationsByHouseholdId\x12\x33.user_account.v2.GetInvitationsByHouseholdIdRequest\x1a\x34.user_account.v2.GetInvitationsByHouseholdIdResponse\x12g\n\x10\x44\x65leteInvitation\x12(.user_account.v2.DeleteInvitationRequest\x1a).user_account.v2.DeleteInvitationResponseB\x91\x01\n!com.aira.contract.user_account.v2B\x13UserInvitationProtoP\x01\xa2\x02\x03UXX\xaa\x02\x0eUserAccount.V2\xca\x02\x0eUserAccount\\V2\xe2\x02\x1aUserAccount\\V2\\GPBMetadata\xea\x02\x0fUserAccount::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_account.v2.user_invitation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.user_account.v2B\023UserInvitationProtoP\001\242\002\003UXX\252\002\016UserAccount.V2\312\002\016UserAccount\\V2\342\002\032UserAccount\\V2\\GPBMetadata\352\002\017UserAccount::V2'
  _globals['_INVITEUSERTOHOUSEHOLDREQUEST']._serialized_start=79
  _globals['_INVITEUSERTOHOUSEHOLDREQUEST']._serialized_end=209
  _globals['_INVITEUSERTOHOUSEHOLDRESPONSE']._serialized_start=211
  _globals['_INVITEUSERTOHOUSEHOLDRESPONSE']._serialized_end=242
  _globals['_ACCEPTINVITATIONREQUEST']._serialized_start=244
  _globals['_ACCEPTINVITATIONREQUEST']._serialized_end=292
  _globals['_ACCEPTINVITATIONRESPONSE']._serialized_start=294
  _globals['_ACCEPTINVITATIONRESPONSE']._serialized_end=320
  _globals['_GETINVITATIONSBYHOUSEHOLDIDREQUEST']._serialized_start=322
  _globals['_GETINVITATIONSBYHOUSEHOLDIDREQUEST']._serialized_end=438
  _globals['_GETINVITATIONSBYHOUSEHOLDIDRESPONSE']._serialized_start=440
  _globals['_GETINVITATIONSBYHOUSEHOLDIDRESPONSE']._serialized_end=521
  _globals['_INVITEE']._serialized_start=523
  _globals['_INVITEE']._serialized_end=555
  _globals['_DELETEINVITATIONREQUEST']._serialized_start=557
  _globals['_DELETEINVITATIONREQUEST']._serialized_end=682
  _globals['_DELETEINVITATIONRESPONSE']._serialized_start=684
  _globals['_DELETEINVITATIONRESPONSE']._serialized_end=710
  _globals['_USERINVITATIONSERVICE']._serialized_start=713
  _globals['_USERINVITATIONSERVICE']._serialized_end=1205
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/state.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/state/v1/state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...command.v1 import set_cool_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__cool__curve__deltas__pb2
from ...command.v1 import set_heat_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__heat__curve__deltas__pb2
from ...command.v1 import set_zone_setpoints_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__zone__setpoints__pb2
from ...config.v1.ccv.v1 import heat_curve_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_ccv_dot_v1_dot_heat__curve__pb2
from . import error_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_error__pb2
from . import features_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_features__pb2
from . import force_heating_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_force__heating__pb2
from . import heat_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_heat__pb2
from . import led_pattern_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_led__pattern__pb2
from . import power_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_power__pb2
from . import versions_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_versions__pb2
from ....wall_thermostat.broadcast.v1 import wall_thermostat_update_pb2 as device_dot_wall__thermostat_dot_broadcast_dot_v1_dot_wall__thermostat__update__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .....schedule.v1 import action_pb2 as schedule_dot_v1_dot_action__pb2
from .....schedule.v1 import schedule_pb2 as schedule_dot_v1_dot_schedule__pb2
from .....util.v1 import time_zone_pb2 as util_dot_v1_dot_time__zone__pb2
from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%device/heat_pump/state/v1/state.proto\x12\x19\x64\x65vice.heat_pump.state.v1\x1a\x37\x64\x65vice/heat_pump/command/v1/set_cool_curve_deltas.proto\x1a\x37\x64\x65vice/heat_pump/command/v1/set_heat_curve_deltas.proto\x1a\x34\x64\x65vice/heat_pump/command/v1/set_zone_setpoints.proto\x1a\x32\x64\x65vice/heat_pump/config/v1/ccv/v1/heat_curve.proto\x1a%device/heat_pump/state/v1/error.proto\x1a(device/heat_pump/state/v1/features.proto\x1a-device/heat_pump/state/v1/force_heating.proto\x1a$device/heat_pump/state/v1/heat.proto\x1a+device/heat_pump/state/v1/led_pattern.proto\x1a%device/heat_pump/state/v1/power.proto\x1a(device/heat_pump/state/v1/versions.proto\x1a@device/wall_thermostat/broadcast/v1/wall_thermostat_update.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18schedule/v1/action.proto\x1a\x1aschedule/v1/schedule.proto\x1a\x17util/v1/time_zone.proto\x1a\x12util/v1/uuid.proto\"\xbd\x14\n\x05State\x12#\n\x0cheat_pump_id\x18\x07 \x01(\x0b\x32\r.util.v1.Uuid\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\ttime_zone\x18) \x01(\x0b\x32\x11.util.v1.TimeZone\x12\x39\n\x15\x61ws_iot_received_time\x18\' \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x1d\x64\x65precated_target_indoor_heat\x18\x02 \x01(\x0b\x32\x1f.device.heat_pump.state.v1.HeatB\x02\x18\x01\x12M\n\x16zone_setpoints_heating\x18\x18 \x01(\x0b\x32-.device.heat_pump.command.v1.ZoneTemperatures\x12$\n\x1ctarget_hot_water_temperature\x18\x03 \x01(\x02\x12%\n\x1d\x63urrent_hot_water_temperature\x18\x04 \x01(\x02\x12#\n\x1b\x63urrent_outdoor_temperature\x18\x08 \x01(\x02\x12\x31\n%deprecated_current_indoor_temperature\x18\t \x01(\x02\x42\x02\x18\x01\x12H\n\x11zone_temperatures\x18\x19 \x01(\x0b\x32-.device.heat_pump.command.v1.ZoneTemperatures\x12%\n\x19\x64\x65precated_linux_build_id\x18\n \x01(\tB\x02\x18\x01\x12:\n\x0bled_pattern\x18\x0c \x01(\x0e\x32%.device.heat_pump.state.v1.LedPattern\x12\x46\n\x11signature_element\x18$ \x01(\x0b\x32+.device.heat_pump.state.v1.SignatureElement\x12\x30\n\x06\x65rrors\x18\r \x03(\x0b\x32 .device.heat_pump.state.v1.Error\x12?\n\x18\x61way_mode_remaining_time\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01\x12,\n\x08\x63\x63v_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x08versions\x18\x10 \x01(\x0b\x32+.device.heat_pump.state.v1.SoftwareVersions\x12 \n\x13manual_mode_enabled\x18\x11 \x01(\x08H\x00\x88\x01\x01\x12\x1f\n\x12night_mode_enabled\x18# \x01(\x08H\x01\x88\x01\x01\x12\x44\n\x10operating_status\x18\x12 \x01(\x0e\x32*.device.heat_pump.state.v1.OperatingStatus\x12:\n\x0bheat_curves\x18\x13 \x01(\x0b\x32%.device.heat_pump.state.v1.HeatCurves\x12G\n\x11heat_curve_deltas\x18\x14 \x01(\x0b\x32,.device.heat_pump.command.v1.HeatCurveDeltas\x12@\n\x0fhot_water_boost\x18\x16 \x01(\x0b\x32#.device.heat_pump.state.v1.DhwBoostB\x02\x18\x01\x12@\n\x0e\x65rror_metadata\x18\x17 \x01(\x0b\x32(.device.heat_pump.state.v1.ErrorMetadata\x12M\n\x16zone_setpoints_cooling\x18\x1b \x01(\x0b\x32-.device.heat_pump.command.v1.ZoneTemperatures\x12:\n\x0b\x63ool_curves\x18\x1c \x01(\x0b\x32%.device.heat_pump.state.v1.CoolCurves\x12G\n\x11\x63ool_curve_deltas\x18\x1d \x01(\x0b\x32,.device.heat_pump.command.v1.CoolCurveDeltas\x12P\n\x1a\x64\x65precated_pump_mode_state\x18\x1e \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeStateB\x02\x18\x01\x12\x16\n\tnum_zones\x18\x1f \x01(\rH\x02\x88\x01\x01\x12:\n\x0bthermostats\x18  \x03(\x0b\x32%.device.heat_pump.state.v1.Thermostat\x12M\n\x17\x63urrent_pump_mode_state\x18! \x01(\x0b\x32,.device.heat_pump.state.v1.ZonePumpModeState\x12I\n\x17\x61llowed_pump_mode_state\x18\" \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\x12G\n\x15\x63onfigured_pump_modes\x18& \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\x12\x36\n\thot_water\x18% \x01(\x0b\x32#.device.heat_pump.state.v1.HotWater\x12\x35\n\x08\x66\x65\x61tures\x18( \x01(\x0b\x32#.device.heat_pump.state.v1.Features\x12\x1d\n\x11\x61way_mode_enabled\x18* \x01(\x08\x42\x02\x18\x01\x12\x37\n\tscheduler\x18+ \x01(\x0b\x32$.device.heat_pump.state.v1.Scheduler\x12\x45\n\x11pump_active_state\x18, \x01(\x0e\x32*.device.heat_pump.state.v1.PumpActiveState\x12!\n\x14inline_heater_active\x18- \x01(\x08H\x03\x88\x01\x01\x12\x39\n\x05power\x18. \x01(\x0b\x32%.device.heat_pump.state.v1.PowerStateH\x04\x88\x01\x01\x12>\n\rforce_heating\x18/ \x01(\x0b\x32\'.device.heat_pump.state.v1.ForceHeating\x12\x44\n\x10power_preference\x18\x30 \x01(\x0e\x32*.device.heat_pump.state.v1.PowerPreferenceB\x16\n\x14_manual_mode_enabledB\x15\n\x13_night_mode_enabledB\x0c\n\n_num_zonesB\x17\n\x15_inline_heater_activeB\x08\n\x06_powerJ\x04\x08\x0b\x10\x0cJ\x04\x08\x06\x10\x07J\x04\x08\x05\x10\x06J\x04\x08\x15\x10\x16J\x04\x08\x1a\x10\x1bR\x10wall_thermostats\"\xa6\x01\n\nHeatCurves\x12K\n\x06zone_1\x18\x01 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearHeatCurve\x12K\n\x06zone_2\x18\x02 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearHeatCurve\"\xa6\x01\n\nCoolCurves\x12K\n\x06zone_1\x18\x01 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearCoolCurve\x12K\n\x06zone_2\x18\x02 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearCoolCurve\"l\n\x08\x44hwBoost\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x18\x01\"\x98\x01\n\rErrorMetadata\x12\x1e\n\x16hp_has_stopping_alarms\x18\x01 \x01(\x08\x12%\n\x1dhp_has_acknowledgeable_alarms\x18\x02 \x01(\x08\x12\x19\n\x11hp_has_some_alarm\x18\x03 \x01(\x08\x12%\n\x1d\x63ompressor_has_stopping_alarm\x18\x04 \x01(\x08\"\x91\x02\n\nThermostat\x12\x16\n\x0e\x61rticle_number\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12N\n\x0blast_update\x18\x03 \x01(\x0b\x32\x39.device.wall_thermostat.broadcast.v1.WallThermostatUpdate\x12\x39\n\x15last_update_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\x04zone\x18\x05 \x01(\x0e\x32\x1f.device.heat_pump.state.v1.Zone\x12\x11\n\x04rssi\x18\x06 \x01(\x05H\x00\x88\x01\x01\x42\x07\n\x05_rssi\"\x87\x01\n\x11ZonePumpModeState\x12\x38\n\x06zone_1\x18\x01 \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\x12\x38\n\x06zone_2\x18\x02 \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\"4\n\x10SignatureElement\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_enabled\"<\n\x08HotWater\x12\x1c\n\x0fheating_enabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x12\n\x10_heating_enabled\"f\n\tScheduler\x12(\n\tschedules\x18\x01 \x03(\x0b\x32\x15.schedule.v1.Schedule\x12/\n\x0e\x61\x63tive_actions\x18\x02 \x03(\x0b\x32\x13.schedule.v1.ActionB\x02\x18\x01*\x90\x01\n\x0fOperatingStatus\x12 \n\x1cOPERATING_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18OPERATING_STATUS_STANDBY\x10\x01\x12\x19\n\x15OPERATING_STATUS_AUTO\x10\x02\x12\"\n\x1eOPERATING_STATUS_USER_SPECIFIC\x10\x03*4\n\x04Zone\x12\x14\n\x10ZONE_UNSPECIFIED\x10\x00\x12\n\n\x06ZONE_1\x10\x01\x12\n\n\x06ZONE_2\x10\x02*\xa9\x01\n\rPumpModeState\x12\x1f\n\x1bPUMP_MODE_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14PUMP_MODE_STATE_IDLE\x10\x01\x12\x1b\n\x17PUMP_MODE_STATE_HEATING\x10\x02\x12\x1b\n\x17PUMP_MODE_STATE_COOLING\x10\x03\x12#\n\x1fPUMP_MODE_STATE_HEATING_COOLING\x10\x04*\xf2\x01\n\x0fPumpActiveState\x12!\n\x1dPUMP_ACTIVE_STATE_UNSPECIFIED\x10\x00\x12\x1a\n\x16PUMP_ACTIVE_STATE_IDLE\x10\x01\x12\x1d\n\x19PUMP_ACTIVE_STATE_HEATING\x10\x02\x12\x1d\n\x19PUMP_ACTIVE_STATE_COOLING\x10\x03\x12\x19\n\x15PUMP_ACTIVE_STATE_DHW\x10\x04\x12%\n!PUMP_ACTIVE_STATE_ANTI_LEGIONELLA\x10\x05\x12 \n\x1cPUMP_ACTIVE_STATE_DEFROSTING\x10\x06*x\n\x0fPowerPreference\x12 \n\x1cPOWER_PREFERENCE_UNSPECIFIED\x10\x00\x12\x1c\n\x18POWER_PREFERENCE_SAVINGS\x10\x01\x12%\n!POWER_PREFERENCE_SELF_CONSUMPTION\x10\x02\x42\xbc\x01\n+com.aira.contract.device.heat_pump.state.v1B\nStateProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.state.v1B\nStateProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_STATE'].fields_by_name['deprecated_target_indoor_heat']._loaded_options = None
  _globals['_STATE'].fields_by_name['deprecated_target_indoor_heat']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['deprecated_current_indoor_temperature']._loaded_options = None
  _globals['_STATE'].fields_by_name['deprecated_current_indoor_temperature']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['deprecated_linux_build_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['deprecated_linux_build_id']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['away_mode_remaining_time']._loaded_options = None
  _globals['_STATE'].fields_by_name['away_mode_remaining_time']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['hot_water_boost']._loaded_options = None
  _globals['_STATE'].fields_by_name['hot_water_boost']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['deprecated_pump_mode_state']._loaded_options = None
  _globals['_STATE'].fields_by_name['deprecated_pump_mode_state']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['away_mode_enabled']._loaded_options = None
  _globals['_STATE'].fields_by_name['away_mode_enabled']._serialized_options = b'\030\001'
  _globals['_DHWBOOST']._loaded_options = None
  _globals['_DHWBOOST']._serialized_options = b'\030\001'
  _globals['_SCHEDULER'].fields_by_name['active_actions']._loaded_options = None
  _globals['_SCHEDULER'].fields_by_name['active_actions']._serialized_options = b'\030\001'
  _globals['_OPERATINGSTATUS']._serialized_start=4672
  _globals['_OPERATINGSTATUS']._serialized_end=4816
  _globals['_ZONE']._serialized_start=4818
  _globals['_ZONE']._serialized_end=4870
  _globals['_PUMPMODESTATE']._serialized_start=4873
  _globals['_PUMPMODESTATE']._serialized_end=5042
  _globals['_PUMPACTIVESTATE']._serialized_start=5045
  _globals['_PUMPACTIVESTATE']._serialized_end=5287
  _globals['_POWERPREFERENCE']._serialized_start=5289
  _globals['_POWERPREFERENCE']._serialized_end=5409
  _globals['_STATE']._serialized_start=811
  _globals['_STATE']._serialized_end=3432
  _globals['_HEATCURVES']._serialized_start=3435
  _globals['_HEATCURVES']._serialized_end=3601
  _globals['_COOLCURVES']._serialized_start=3604
  _globals['_COOLCURVES']._serialized_end=3770
  _globals['_DHWBOOST']._serialized_start=3772
  _globals['_DHWBOOST']._serialized_end=3880
  _globals['_ERRORMETADATA']._serialized_start=3883
  _globals['_ERRORMETADATA']._serialized_end=4035
  _globals['_THERMOSTAT']._serialized_start=4038
  _globals['_THERMOSTAT']._serialized_end=4311
  _globals['_ZONEPUMPMODESTATE']._serialized_start=4314
  _globals['_ZONEPUMPMODESTATE']._serialized_end=4449
  _globals['_SIGNATUREELEMENT']._serialized_start=4451
  _globals['_SIGNATUREELEMENT']._serialized_end=4503
  _globals['_HOTWATER']._serialized_start=4505
  _globals['_HOTWATER']._serialized_end=4565
  _globals['_SCHEDULER']._serialized_start=4567
  _globals['_SCHEDULER']._serialized_end=4669
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/command_source.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/command/v1/command_source.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0device/heat_pump/command/v1/command_source.proto\x12\x1b\x64\x65vice.heat_pump.command.v1*\xe0\x01\n\rCommandSource\x12\x1e\n\x1a\x43OMMAND_SOURCE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43OMMAND_SOURCE_APP_CONTROL\x10\x01\x12(\n$COMMAND_SOURCE_GOVERNMENT_REGULATION\x10\x05\x12 \n\x1c\x43OMMAND_SOURCE_SMART_CONTROL\x10\x02\x12\x1f\n\x1b\x43OMMAND_SOURCE_THINGS_BOARD\x10\x03\x12\"\n\x1e\x43OMMAND_SOURCE_WALL_THERMOSTAT\x10\x04\x42\xce\x01\n-com.aira.contract.device.heat_pump.command.v1B\x12\x43ommandSourceProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.command_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.aira.contract.device.heat_pump.command.v1B\022CommandSourceProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_COMMANDSOURCE']._serialized_start=82
  _globals['_COMMANDSOURCE']._serialized_end=306
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/versions.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/state/v1/versions.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(device/heat_pump/state/v1/versions.proto\x12\x19\x64\x65vice.heat_pump.state.v1\"\xdc\x01\n\x10SoftwareVersions\x12\x16\n\x0elinux_build_id\x18\x01 \x01(\t\x12\x1c\n\x14\x63onnectivity_manager\x18\x02 \x01(\t\x12\x0f\n\x07\x63m_care\x18\x03 \x01(\t\x12\x17\n\x0fsilabs_firmware\x18\x04 \x01(\t\x12\x1d\n\x15\x63limate_control_villa\x18\x05 \x01(\t\x12 \n\x18outdoor_unit_application\x18\x08 \x01(\t\x12\x1b\n\x13outdoor_unit_eeprom\x18\t \x01(\tJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\x42\xbf\x01\n+com.aira.contract.device.heat_pump.state.v1B\rVersionsProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.versions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.state.v1B\rVersionsProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_SOFTWAREVERSIONS']._serialized_start=72
  _globals['_SOFTWAREVERSIONS']._serialized_end=292
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: notification/v1/notification_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'notification/v1/notification_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import notification_pb2 as notification_dot_v1_dot_notification__pb2
from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*notification/v1/notification_service.proto\x12\x0fnotification.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"notification/v1/notification.proto\x1a\x12util/v1/uuid.proto\"s\n\x17GetNotificationsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x34\n\x10\x63reated_at_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x18\x01\"T\n\x18GetNotificationsResponse\x12\x34\n\rnotifications\x18\x01 \x03(\x0b\x32\x1d.notification.v1.Notification:\x02\x18\x01\"e\n\x17ReadNotificationRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12&\n\x0fnotification_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid:\x02\x18\x01\"\x1e\n\x18ReadNotificationResponse:\x02\x18\x01\"M\n\x18\x41\x64\x64\x46\x63mTokenToUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05token\x18\x02 \x01(\t:\x02\x18\x01\"\x1f\n\x19\x41\x64\x64\x46\x63mTokenToUserResponse:\x02\x18\x01\"R\n\x1dRemoveFcmTokenFromUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05token\x18\x02 \x01(\t:\x02\x18\x01\"$\n\x1eRemoveFcmTokenFromUserResponse:\x02\x18\x01\x32\xd3\x03\n\x13NotificationService\x12g\n\x10GetNotifications\x12(.notification.v1.GetNotificationsRequest\x1a).notification.v1.GetNotificationsResponse\x12g\n\x10ReadNotification\x12(.notification.v1.ReadNotificationRequest\x1a).notification.v1.ReadNotificationResponse\x12j\n\x11\x41\x64\x64\x46\x63mTokenToUser\x12).notification.v1.AddFcmTokenToUserRequest\x1a*.notification.v1.AddFcmTokenToUserResponse\x12y\n\x16RemoveFcmTokenFromUser\x12..notification.v1.RemoveFcmTokenFromUserRequest\x1a/.notification.v1.RemoveFcmTokenFromUserResponse\x1a\x03\x88\x02\x01\x42\x9a\x01\n!com.aira.contract.notification.v1B\x18NotificationServiceProtoP\x01\xa2\x02\x03NXX\xaa\x02\x0fNotification.V1\xca\x02\x0fNotification\\V1\xe2\x02\x1bNotification\\V1\\GPBMetadata\xea\x02\x10Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification.v1.notification_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.notification.v1B\030NotificationServiceProtoP\001\242\002\003NXX\252\002\017Notification.V1\312\002\017Notification\\V1\342\002\033Notification\\V1\\GPBMetadata\352\002\020Notification::V1'
  _globals['_GETNOTIFICATIONSREQUEST']._loaded_options = None
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_options = b'\030\001'
  _globals['_GETNOTIFICATIONSRESPONSE']._loaded_options = None
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_options = b'\030\001'
  _globals['_READNOTIFICATIONREQUEST']._loaded_options = None
  _globals['_READNOTIFICATIONREQUEST']._serialized_options = b'\030\001'
  _globals['_READNOTIFICATIONRESPONSE']._loaded_options = None
  _globals['_READNOTIFICATIONRESPONSE']._serialized_options = b'\030\001'
  _globals['_ADDFCMTOKENTOUSERREQUEST']._loaded_options = None
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_options = b'\030\001'
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._loaded_options = None
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_options = b'\030\001'
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._loaded_options = None
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_options = b'\030\001'
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._loaded_options = None
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_options = b'\030\001'
  _globals['_NOTIFICATIONSERVICE']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE']._serialized_options = b'\210\002\001'
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_start=152
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_end=267
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_start=269
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_end=353
  _globals['_READNOTIFICATIONREQUEST']._serialized_start=355
  _globals['_READNOTIFICATIONREQUEST']._serialized_end=456
  _globals['_READNOTIFICATIONRESPONSE']._serialized_start=458
  _globals['_READNOTIFICATIONRESPONSE']._serialized_end=488
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_start=490
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_end=567
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_start=569
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_end=600
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_start=602
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_end=684
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_start=686
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_end=722
  _globals['_NOTIFICATIONSERVICE']._serialized_start=725
  _globals['_NOTIFICATIONSERVICE']._serialized_end=1192
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import user_account_pb2 as user__account_dot_v2_dot_user__account__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in user_account/v2/user_account_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UserAccountServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddHeatPumpPermissions = channel.unary_unary(
                '/user_account.v2.UserAccountService/AddHeatPumpPermissions',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.AddHeatPumpPermissionsRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.AddHeatPumpPermissionsResponse.FromString,
                _registered_method=True)
        self.ConfirmEmailChange = channel.unary_unary(
                '/user_account.v2.UserAccountService/ConfirmEmailChange',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.ConfirmEmailChangeRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.ConfirmEmailChangeResponse.FromString,
                _registered_method=True)
        self.ConfirmPhoneNumber = channel.unary_unary(
                '/user_account.v2.UserAccountService/ConfirmPhoneNumber',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.ConfirmPhoneNumberRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.ConfirmPhoneNumberResponse.FromString,
                _registered_method=True)
        self.GetUserAccountByContactId = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetUserAccountByContactId',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByContactIdRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByContactIdResponse.FromString,
                _registered_method=True)
        self.GetUserAccountByCognitoId = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetUserAccountByCognitoId',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByCognitoIdRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByCognitoIdResponse.FromString,
                _registered_method=True)
        self.GetUserAccountByUserId = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetUserAccountByUserId',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByUserIdRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByUserIdResponse.FromString,
                _registered_method=True)
        self.CreateUserAccount = channel.unary_unary(
                '/user_account.v2.UserAccountService/CreateUserAccount',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.CreateUserAccountRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.CreateUserAccountResponse.FromString,
                _registered_method=True)
        self.UpdateUserAccount = channel.unary_unary(
                '/user_account.v2.UserAccountService/UpdateUserAccount',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.UpdateUserAccountRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.UpdateUserAccountResponse.FromString,
                _registered_method=True)
        self.AdminUpdateUser = channel.unary_unary(
                '/user_account.v2.UserAccountService/AdminUpdateUser',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.AdminUpdateUserRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.AdminUpdateUserResponse.FromString,
                _registered_method=True)
        self.AdminCreateInstallerAccount = channel.unary_unary(
                '/user_account.v2.UserAccountService/AdminCreateInstallerAccount',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.AdminCreateInstallerAccountRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.AdminCreateInstallerAccountResponse.FromString,
                _registered_method=True)
        self.AdminFindInstallerAccount = channel.unary_unary(
                '/user_account.v2.UserAccountService/AdminFindInstallerAccount',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.AdminFindInstallerAccountRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.AdminFindInstallerAccountResponse.FromString,
                _registered_method=True)
        self.AdminUpdateInstallerAccount = channel.unary_unary(
                '/user_account.v2.UserAccountService/AdminUpdateInstallerAccount',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.AdminUpdateInstallerAccountRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.AdminUpdateInstallerAccountResponse.FromString,
                _registered_method=True)
        self.GetAllUserAgreements = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetAllUserAgreements',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetAllUserAgreementsRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetAllUserAgreementsResponse.FromString,
                _registered_method=True)
        self.CreateLegalDocumentUserAgreement = channel.unary_unary(
                '/user_account.v2.UserAccountService/CreateLegalDocumentUserAgreement',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.CreateLegalDocumentUserAgreementRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.CreateLegalDocumentUserAgreementResponse.FromString,
                _registered_method=True)
        self.UserHasAcceptedLatestLegalDocuments = channel.unary_unary(
                '/user_account.v2.UserAccountService/UserHasAcceptedLatestLegalDocuments',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.UserHasAcceptedLatestLegalDocumentsRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.UserHasAcceptedLatestLegalDocumentsResponse.FromString,
                _registered_method=True)
        self.GetHeatPumpZoneNames = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetHeatPumpZoneNames',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetHeatPumpZoneNamesRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetHeatPumpZoneNamesResponse.FromString,
                _registered_method=True)
        self.GetUserAccountsByHeatPumpId = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetUserAccountsByHeatPumpId',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountsByHeatPumpIdRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountsByHeatPumpIdResponse.FromString,
                _registered_method=True)
        self.GetHouseholdsByUserId = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetHouseholdsByUserId',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetHouseholdsByUserIdRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetHouseholdsByUserIdResponse.FromString,
                _registered_method=True)
        self.DeleteResident = channel.unary_unary(
                '/user_account.v2.UserAccountService/DeleteResident',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.DeleteResidentRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.DeleteResidentResponse.FromString,
                _registered_method=True)
        self.GetFeaturesAsNotifications = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetFeaturesAsNotifications',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetFeaturesAsNotificationsRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetFeaturesAsNotificationsResponse.FromString,
                _registered_method=True)
        self.GetProximityVerificationStatus = channel.unary_unary(
                '/user_account.v2.UserAccountService/GetProximityVerificationStatus',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.GetProximityVerificationStatusRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.GetProximityVerificationStatusResponse.FromString,
                _registered_method=True)
        self.VerifyProximity = channel.unary_unary(
                '/user_account.v2.UserAccountService/VerifyProximity',
                request_serializer=user__account_dot_v2_dot_user__account__pb2.VerifyProximityRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__account__pb2.VerifyProximityResponse.FromString,
                _registered_method=True)


class UserAccountServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddHeatPumpPermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmEmailChange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmPhoneNumber(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserAccountByContactId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserAccountByCognitoId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserAccountByUserId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminUpdateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminCreateInstallerAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminFindInstallerAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminUpdateInstallerAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllUserAgreements(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLegalDocumentUserAgreement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserHasAcceptedLatestLegalDocuments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHeatPumpZoneNames(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserAccountsByHeatPumpId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHouseholdsByUserId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteResident(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturesAsNotifications(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProximityVerificationStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyProximity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserAccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddHeatPumpPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.AddHeatPumpPermissions,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.AddHeatPumpPermissionsRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.AddHeatPumpPermissionsResponse.SerializeToString,
            ),
            'ConfirmEmailChange': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmEmailChange,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.ConfirmEmailChangeRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.ConfirmEmailChangeResponse.SerializeToString,
            ),
            'ConfirmPhoneNumber': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmPhoneNumber,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.ConfirmPhoneNumberRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.ConfirmPhoneNumberResponse.SerializeToString,
            ),
            'GetUserAccountByContactId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserAccountByContactId,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByContactIdRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByContactIdResponse.SerializeToString,
            ),
            'GetUserAccountByCognitoId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserAccountByCognitoId,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByCognitoIdRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByCognitoIdResponse.SerializeToString,
            ),
            'GetUserAccountByUserId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserAccountByUserId,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByUserIdRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountByUserIdResponse.SerializeToString,
            ),
            'CreateUserAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserAccount,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.CreateUserAccountRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.CreateUserAccountResponse.SerializeToString,
            ),
            'UpdateUserAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserAccount,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.UpdateUserAccountRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.UpdateUserAccountResponse.SerializeToString,
            ),
            'AdminUpdateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminUpdateUser,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.AdminUpdateUserRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.AdminUpdateUserResponse.SerializeToString,
            ),
            'AdminCreateInstallerAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminCreateInstallerAccount,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.AdminCreateInstallerAccountRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.AdminCreateInstallerAccountResponse.SerializeToString,
            ),
            'AdminFindInstallerAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminFindInstallerAccount,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.AdminFindInstallerAccountRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.AdminFindInstallerAccountResponse.SerializeToString,
            ),
            'AdminUpdateInstallerAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminUpdateInstallerAccount,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.AdminUpdateInstallerAccountRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.AdminUpdateInstallerAccountResponse.SerializeToString,
            ),
            'GetAllUserAgreements': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllUserAgreements,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetAllUserAgreementsRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetAllUserAgreementsResponse.SerializeToString,
            ),
            'CreateLegalDocumentUserAgreement': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLegalDocumentUserAgreement,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.CreateLegalDocumentUserAgreementRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.CreateLegalDocumentUserAgreementResponse.SerializeToString,
            ),
            'UserHasAcceptedLatestLegalDocuments': grpc.unary_unary_rpc_method_handler(
                    servicer.UserHasAcceptedLatestLegalDocuments,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.UserHasAcceptedLatestLegalDocumentsRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.UserHasAcceptedLatestLegalDocumentsResponse.SerializeToString,
            ),
            'GetHeatPumpZoneNames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHeatPumpZoneNames,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetHeatPumpZoneNamesRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetHeatPumpZoneNamesResponse.SerializeToString,
            ),
            'GetUserAccountsByHeatPumpId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserAccountsByHeatPumpId,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountsByHeatPumpIdRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetUserAccountsByHeatPumpIdResponse.SerializeToString,
            ),
            'GetHouseholdsByUserId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHouseholdsByUserId,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetHouseholdsByUserIdRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetHouseholdsByUserIdResponse.SerializeToString,
            ),
            'DeleteResident': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteResident,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.DeleteResidentRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.DeleteResidentResponse.SerializeToString,
            ),
            'GetFeaturesAsNotifications': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesAsNotifications,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetFeaturesAsNotificationsRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetFeaturesAsNotificationsResponse.SerializeToString,
            ),
            'GetProximityVerificationStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProximityVerificationStatus,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.GetProximityVerificationStatusRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.GetProximityVerificationStatusResponse.SerializeToString,
            ),
            'VerifyProximity': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyProximity,
                    request_deserializer=user__account_dot_v2_dot_user__account__pb2.VerifyProximityRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__account__pb2.VerifyProximityResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'user_account.v2.UserAccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('user_account.v2.UserAccountService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserAccountService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddHeatPumpPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/AddHeatPumpPermissions',
            user__account_dot_v2_dot_user__account__pb2.AddHeatPumpPermissionsRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.AddHeatPumpPermissionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConfirmEmailChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/ConfirmEmailChange',
            user__account_dot_v2_dot_user__account__pb2.ConfirmEmailChangeRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.ConfirmEmailChangeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConfirmPhoneNumber(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/ConfirmPhoneNumber',
            user__account_dot_v2_dot_user__account__pb2.ConfirmPhoneNumberRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.ConfirmPhoneNumberResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserAccountByContactId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetUserAccountByContactId',
            user__account_dot_v2_dot_user__account__pb2.GetUserAccountByContactIdRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetUserAccountByContactIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserAccountByCognitoId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetUserAccountByCognitoId',
            user__account_dot_v2_dot_user__account__pb2.GetUserAccountByCognitoIdRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetUserAccountByCognitoIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserAccountByUserId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetUserAccountByUserId',
            user__account_dot_v2_dot_user__account__pb2.GetUserAccountByUserIdRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetUserAccountByUserIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateUserAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/CreateUserAccount',
            user__account_dot_v2_dot_user__account__pb2.CreateUserAccountRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.CreateUserAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateUserAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/UpdateUserAccount',
            user__account_dot_v2_dot_user__account__pb2.UpdateUserAccountRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.UpdateUserAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AdminUpdateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/AdminUpdateUser',
            user__account_dot_v2_dot_user__account__pb2.AdminUpdateUserRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.AdminUpdateUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AdminCreateInstallerAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/AdminCreateInstallerAccount',
            user__account_dot_v2_dot_user__account__pb2.AdminCreateInstallerAccountRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.AdminCreateInstallerAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AdminFindInstallerAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/AdminFindInstallerAccount',
            user__account_dot_v2_dot_user__account__pb2.AdminFindInstallerAccountRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.AdminFindInstallerAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AdminUpdateInstallerAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/AdminUpdateInstallerAccount',
            user__account_dot_v2_dot_user__account__pb2.AdminUpdateInstallerAccountRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.AdminUpdateInstallerAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAllUserAgreements(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetAllUserAgreements',
            user__account_dot_v2_dot_user__account__pb2.GetAllUserAgreementsRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetAllUserAgreementsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateLegalDocumentUserAgreement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/CreateLegalDocumentUserAgreement',
            user__account_dot_v2_dot_user__account__pb2.CreateLegalDocumentUserAgreementRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.CreateLegalDocumentUserAgreementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UserHasAcceptedLatestLegalDocuments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/UserHasAcceptedLatestLegalDocuments',
            user__account_dot_v2_dot_user__account__pb2.UserHasAcceptedLatestLegalDocumentsRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.UserHasAcceptedLatestLegalDocumentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetHeatPumpZoneNames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetHeatPumpZoneNames',
            user__account_dot_v2_dot_user__account__pb2.GetHeatPumpZoneNamesRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetHeatPumpZoneNamesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserAccountsByHeatPumpId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetUserAccountsByHeatPumpId',
            user__account_dot_v2_dot_user__account__pb2.GetUserAccountsByHeatPumpIdRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetUserAccountsByHeatPumpIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetHouseholdsByUserId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetHouseholdsByUserId',
            user__account_dot_v2_dot_user__account__pb2.GetHouseholdsByUserIdRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetHouseholdsByUserIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteResident(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/DeleteResident',
            user__account_dot_v2_dot_user__account__pb2.DeleteResidentRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.DeleteResidentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFeaturesAsNotifications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetFeaturesAsNotifications',
            user__account_dot_v2_dot_user__account__pb2.GetFeaturesAsNotificationsRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetFeaturesAsNotificationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetProximityVerificationStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/GetProximityVerificationStatus',
            user__account_dot_v2_dot_user__account__pb2.GetProximityVerificationStatusRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.GetProximityVerificationStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VerifyProximity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserAccountService/VerifyProximity',
            user__account_dot_v2_dot_user__account__pb2.VerifyProximityRequest.SerializeToString,
            user__account_dot_v2_dot_user__account__pb2.VerifyProximityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


""" Class containing default settings for the application. """
# config/settings.py

class Settings:
    USER_POOL_IDS = ["eu-north-1_cnqyjWtbz", "eu-north-1_EyCYO6SAa", "eu-north-1_k0IgmZxLJ"]
    CLIENT_ID = "5eehn0b5d6fsg28rjc5p1u0vi6"
    AIRA_BACKEND = "engagementbff.prod.airahome.com:443"
    USER_AGENT = "AiraApp 1.4.7"
    APP_PACKAGE = "com.airahome.aira"
    APP_VERSION = "1.4.7"
    ALLOWED_COMMANDS = ["set_zone_setpoints", "set_away_mode", "clear_away_mode", "activate_hot_water_boosting", "deactivate_hot_water_boosting", "activate_night_mode_for_one_hour", "set_target_hot_water_temperature", "set_wifi_credentials", "update_linux", "rotate_certificate", "turn_signature_element_lights_on", "turn_signature_element_lights_off", "acknowledge_errors", "disconnect_wifi", "install_app_package", "install_firmware", "configure_heat_pump", "configure_time_zone", "factory_reset", "set_heat_curve_deltas", "clear_heat_curve_delta", "ping", "set_flow_alarm_thresholds", "set_outdoor_unit_current_limits", "set_cool_curve_deltas", "clear_cool_curve_delta", "update_system", "set_heat_curves", "set_cool_curves", "regenerate_thread_config", "set_diagnostic_poll_period", "enable_hot_water_heating", "disable_hot_water_heating", "modbus", "run_legionella_cycle", "reset_legionella_schedule", "decommission_wall_thermostat", "set_heating_cooling_thresholds", "set_pump_speed_settings", "set_inline_heater_steps", "set_sensor_sources", "set_energy_balance_thresholds", "disable_manual_mode", "reboot_device", "set_scheduled_heat_curve_deltas", "clear_scheduled_heat_curve_deltas", "set_telemetry_interval", "allow_lte", "forbid_lte", "update_lte_hysteresis", "set_inline_heater_ambient_threshold", "add_schedule", "remove_schedule", "pair_ferroamp_core", "zone_heating_regulator", "unpair_ferroamp_core", "sync_ferroamp_devices", "sync_ferroamp_cts", "enable_force_heating", "disable_force_heating", "set_power_preference"]


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/led_pattern.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/state/v1/led_pattern.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+device/heat_pump/state/v1/led_pattern.proto\x12\x19\x64\x65vice.heat_pump.state.v1*\xdf\x02\n\nLedPattern\x12\x1b\n\x17LED_PATTERN_UNSPECIFIED\x10\x00\x12\x15\n\x11LED_PATTERN_BLACK\x10\t\x12\x16\n\x12LED_PATTERN_NORMAL\x10\x01\x12\x1d\n\x19LED_PATTERN_COMMISSIONING\x10\x02\x12\x1a\n\x16LED_PATTERN_PROCESSING\x10\x03\x12\x17\n\x13LED_PATTERN_COOLING\x10\x0b\x12\x19\n\x15LED_PATTERN_ATTENTION\x10\x04\x12\x19\n\x15LED_PATTERN_AWAY_MODE\x10\x05\x12$\n LED_PATTERN_ERROR_UNACKNOWLEDGED\x10\x06\x12\"\n\x1eLED_PATTERN_ERROR_ACKNOWLEDGED\x10\x07\x12\x17\n\x13LED_PATTERN_CONFIRM\x10\x08\x12\x18\n\x14LED_PATTERN_BOOSTING\x10\nB\xc1\x01\n+com.aira.contract.device.heat_pump.state.v1B\x0fLedPatternProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.led_pattern_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.state.v1B\017LedPatternProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_LEDPATTERN']._serialized_start=75
  _globals['_LEDPATTERN']._serialized_end=426
# @@protoc_insertion_point(module_scope)